//
//  GBImageUtilities.h
//  gBrowser
//
//  Created by andreas on Wed Oct 17 2001.

#import <Cocoa/Cocoa.h>

typedef enum {
    GBSharpenExtraHigh,
    GBSharpenHigh,
    GBSharpenMedium,
    GBSharpenLow,
    GBSharpenNone,
    GBSharpenExtraLow
} GBImageSharpenOptions;

typedef struct {
    float topRight;
    float topMiddle;
    float topLeft;
    float midRight;
    float center;
    float midLeft;
    float bottomRight;
    float bottomMiddle;
    float bottomLeft;
} GBMatrix;

extern GBMatrix standardMatrix;
extern GBMatrix standardMatrixExtraLow;
extern GBMatrix standardMatrixLow;
extern GBMatrix standardMatrixMedium;
extern GBMatrix standardMatrixHigh;
extern GBMatrix standardMatrixExtraHigh;

@class GBFile;

@interface NSImage (GBImageUtilities)

- (NSSize)sizeWithMaxDimension:(int)max;

- (NSBitmapImageRep *)bitmapImageRepForSize:(NSSize)size;
- (NSBitmapImageRep *)lowQualityBitmapImageRepForSize:(NSSize)size;

- (NSImage *)imageSharpenedByATinyBit;
- (NSImage *)imageSharpenedByAmount:(int)amount;
- (NSImage *)imageFilteredWithMatrix:(GBMatrix)matrix;

// Returned icon image must be released afterward
+ (NSImage *)createIconImageForFile:(GBFile *)file;

+ (NSImage *)trashImage;
+ (NSImage *)deleteImage;
+ (NSImage *)newFolderImage;

+ (NSImage *)openFolder;
+ (NSImage *)genericFolder;
+ (NSImage *)genericDocument;
+ (NSImage *)genericApplication;

+ (NSImage *)leftArrowImage;
+ (NSImage *)rightArrowImage;

+ (NSImage *)generatePreviewIconImage;

+ (NSImage *)pathImage;

+ (NSImage *)computerIcon;

+ (NSImage *)scrollMenuImage;

+ (NSImage *)dropDownArrowImage;

+ (NSImage *)dropRightArrowImage;

// Thumbnails
+ (CGImageRef)getPreviewResourceForFile:(GBFile *)file;

@end




